parse_ws_order_book_deltas

Function parse_ws_order_book_deltas 

pub fn parse_ws_order_book_deltas(
    book: &LighterWsOrderBook,
    instrument: &InstrumentAny,
    timestamp_ms: u64,
    is_snapshot: bool,
    ts_init: UnixNanos,
) -> Result<OrderBookDeltas>
Parses a Lighter order book update into Nautilus deltas.

is_snapshot must be supplied by the caller because Lighter sends subscribed/order_book for the full book on subscription and update/order_book for incremental level changes afterwards.

Errors

Returns an error if any price or size cannot be converted.