parse_ws_trade_tick

Function parse_ws_trade_tick 

pub fn parse_ws_trade_tick(
    trade: &LighterTrade,
    instrument: &InstrumentAny,
    ts_init: UnixNanos,
) -> Result<TradeTick>
Parses a Lighter trade stream item into a Nautilus [TradeTick].

Errors

Returns an error if the trade cannot be converted into a Nautilus tick.