pub fn parse_ws_trade_tick(
trade: &LighterTrade,
instrument: &InstrumentAny,
ts_init: UnixNanos,
) -> Result<TradeTick>Expand description
Parses a Lighter trade stream item into a Nautilus [TradeTick].
Errors
Returns an error if the trade cannot be converted into a Nautilus tick.